@@ -13,46 +13,42 @@ def curve_fit_ode(model,
     param_var0=None,
     guess0=None,
     bounds=None,
-    col_index=-1,
+    x_ind=-1,
     n_opt = 0
     ):
 
     """
-    Use non-linear least squares to fit results of ordinary differential
-    equations (model), to data.
+    Uses non-linear least squares to fit results of ODE (model) to data.
 
     Args:
         model (callable(y,t,...)): The function computes the derivative of y at t.
         var0 (callable or array): Initial condition of var.
-        t (array): A sequence of time points for which to solve for y. The initial
-                    value point should be the first element of this sequence.
-        xdata (array): The independent variable where the data is measured.
-                                Should usually be an M-length sequence or an
-                                (k, M)-shaped array for functions with k predictors,
-                                but can actually be any object.
-        ydata (array): The dependent data, a length M array - nominally
-                                f(xdata, ...).
-                                
-        param (array, optional): Parameters used in the ode model function.
+        t (array): A sequence of time points for which to solve for y.
+        xdata (array):  The independent variable where the data is measured.
+                        Should usually be an M-length sequence or an
+                        (k,M)-shaped array for functions with k predictors,
+                        but can actually be any object.
+        ydata (array): The dependent data, a length M array - nominally f(xdata, ...).                    
+        param (array, optional): Parameters used in the ODE model function.
         param_var0 (array, optional): Parameters used in the initial condition function.
-
         guess0 (array, optional): Initial guess for the parameters (length N). If None,
-                                then the initial values will all be 1 (if the number of
-                                parameters for the function can be determined using
-                                introspection, otherwise a ValueError is raised).
-        bounds (2-tuple of array_like, optional): Lower and upper bounds on parameters.
-                                                   Defaults to [0.1*guess0, 1.5*guess0].
-        col_index (int, optional): The index of fitted results in the solved list
-                                    of the model. The default will be the last column of
-                                    the list.
-        n_opt (int, optional): If the model consists of n CSTRs this is to choose which CSTR should be chosen for the fitting. Default to the last CSTR.
+                                  then the initial values will all be 1 (if the number of
+                                  parameters for the function can be determined using
+                                  introspection, otherwise a ValueError is raised).
+        bounds (2-tuple of array_like, optional): Lower and upper bounds of parameters.
+                                                  Defaults to [0.1*guess0, 1.5*guess0].
+        x_ind (int, optional): The index of fitted results in the solved list
+                               of the model. The default is the last column of
+                               the list.
+        n_opt (int, optional): For a model of n CSTRs, this defines which CSTR is used for the fitting. Default is the last CSTR.
 
     Returns:
         avg: Optimal values for the parameters so that the sum of the squared residuals
                 of f(xdata, *popt) - ydata is minimized.
-        std: The estimated covariance of avg. The diagonals provide the variance of the
+        cov: The estimated covariance of avg. The diagonals provide the variance of the
                 parameter estimate.
     """
+    
     if isinstance(param, int) | isinstance(param, float):
         param = [param]
     if isinstance(param_var0, int) | isinstance(param_var0, float):
@@ -65,20 +61,19 @@ def curve_fit_ode(model,
         xdata.loc[-1] = 0
         xdata.index = xdata.index + 1
         xdata = xdata.sort_index()
-        ydata.loc[-1] = np.math.nan
+        ydata.loc[-1] = np.nan
         ydata.index = ydata.index + 1
         ydata = ydata.sort_index()
                          
-    try:
+    if callable(var0):
         df = sol_ode(model, var0(param_var0), t, param)
-    except:
-        df = sol_ode(model, var0, t, param)
+    else: df = sol_ode(model, var0, t, param)
         
     if isinstance(df,list):
-        C = df[col_index]
+        C = df[x_ind]
         if isinstance(C,np.ndarray):
             if C.ndim > 1:
-                C = df[col_index][:,n_opt-1]
+                C = df[x_ind][:,n_opt-1]
             else: pass
         else: pass
     elif isinstance(df,np.ndarray):
@@ -127,19 +122,19 @@ def curve_fit_ode(model,
         for i in range(len(p1)):
             param_new[p1_converse[i]] = args[p1[i]]
 
-        try:
+        if callable(var0):
             # change the parameter in the initial condition
             param_var0_new = param_var0
             for i in range(len(p0)):
                 param_var0_new[p0_converse[i]] = args[p0[i]]
             # solve the ode function
             results = sol_ode(model, var0(param_var0_new), xdata, param_new)
-        except:
+        else:
             results = sol_ode(model, var0, xdata, param_new)
 
         # return the solved result
         if isinstance(results,list):
-            ar = results[col_index]
+            ar = results[x_ind]
             if isinstance(ar,np.ndarray):
                 if ar.ndim > 1:
                     return ar[:,n_opt-1][~np.isnan(ydata)]
@@ -152,18 +147,18 @@ def curve_fit_ode(model,
         else: raise('Output of the model must be list or array.')
         
         
-    avg, std = sp.optimize.curve_fit(func, xdata, ydata[~np.isnan(ydata)], p0=guess0, bounds=bounds)
-    try:
+    avg, cov = sp.optimize.curve_fit(func, xdata, ydata[~np.isnan(ydata)], p0=guess0, bounds=bounds)
+    if callable(var0):
          df = sol_ode(model, var0(param_var0), t, param)
-    except:
+    else:
          df = sol_ode(model, var0, t, param)
     
         
     if isinstance(df,list):
-        Cnew = df[col_index]
+        Cnew = df[x_ind]
         if isinstance(Cnew,np.ndarray):
             if Cnew.ndim > 1:
-                Cnew = df[col_index][:,n_opt-1]
+                Cnew = df[x_ind][:,n_opt-1]
             else: pass
         else: pass
     elif isinstance(df,np.ndarray):
@@ -175,8 +170,9 @@ def curve_fit_ode(model,
     plt.figure('curve fit')
     plt.plot(t,Cnew,color='red',linestyle='dashed')
     plt.legend(["measured data","model","fitted model"])
-    plt.show()
     
-    print("average:", avg)
+    print("Original vs fitted average values:", guess0, avg)
+    std = np.sqrt(np.diag(cov))
+    print("Standard deviation of estimated parameters:", std)
     
-    return avg, std
\ No newline at end of file
+    return avg, cov
\ No newline at end of file
