@@ -3,13 +3,13 @@ import pandas as pd
 def data_import(file,columnnames):
 
     """
-    Import files from the input file position.
+    Imports a file and renames the columns.
 
     Args:
         file (str): The location of the file.
 
     Returns:
-        data (Dataframe): The table contains time and concentration values.
+        data (Dataframe): In case of SAMM the table mostly contains time and concentration values.
     """
 
     data = pd.read_csv(file, sep="\t|,|;", engine='python')
