@@ -5,13 +5,14 @@ import pandas as pd
 def fft(data):
 
     """
-    Compute the 1-D discrete Fourier Transformation. 
+    Computes the 1-D discrete Fourier Transformation. 
     
     Args:
-        data (dataframe or list): The dataframe or list with two columns, first: time, second: value
+        data (dataframe or list): The dataframe or list with two columns, first: time, second: value.
+    
     Returns:
-        frq (array): x-axis of the descrete frequency spectrum 
-        amp (array): y-axis of the descrete frequency spectrum 
+        frq (array): x-axis (= frequency) of the descrete frequency spectrum. 
+        amp (array): y-axis (= amplitude) of the descrete frequency spectrum. 
     """
 
     # acess data frame or list. Raise error if neither is given.
