@@ -6,14 +6,11 @@ def limit(a, a_min):
     Limit the values in an array or one value.
 
     Args:
-        a (array_like or float): Array containing elements to clip or elements to
-                                 clip.
-        a_min (array_like or None): Minimum value in the clipped list or the clipped
-                                    value.
+        a (array_like or float): Array containing elements to clip or element to clip.
+        a_min (array_like or None): Minimum value in the clipped array or the clipped element.
 
     Returns:
-        array_like: An array with the elements of a, but where values < a_min are
-                    replaced with a_min.
+        array_like: An array with the elements of a, but where values < a_min are replaced with a_min.
     """
 
     # limit the value with int or float type
