@@ -1,11 +1,17 @@
 import numpy as np
-
+    
 def nextprime(n):
+    
     """
-    target: finds the next prime number
-    param n: any number (int)
-    return: prime number (int)
+    Finds the next prime number.
+    
+    Args:
+        n (int): Any number.
+    
+    Returns:
+        p (int): Next prime number.
     """ 
+    
     p=n+1
     for i in range(2,p):
         if(np.mod(p,i)==0):
