@@ -5,22 +5,21 @@ import scipy as sp
 import odeintw as ow
 import tqdm as tq
 
-
 def sol_ode(model, var0, t, param):
 
     """
-    Solve a system of ordinary differential equations.
+    Solves a system of ordinary differential equations (ODEs).
     
     Args:
         model (callable(var,t,param)): The function computes the derivative of y at t.
         var0 (array): Initial condition of var.
-        t (array):  A sequence of time points for which to solve for var. The initial
-                    value point should be the first element of this sequence.
-        param (array): model parameters.
+        t (array): A sequence of time points at which var is calculated.
+        param (array): Model parameters.
 
     Returns:
-        ar (array): Array containing the value of var for each desired time in t, with the initial value var0 in the first row
+        ar (array): Array containing the value of var for each desired time in t, with the initial value var0 in the first row.
     """
+    
     dt = t[1]-t[0]
     if isinstance(param,list):
         if (len(param) == 1):
